TemplateGenerator class

Generator for Serverpod VPS deployment files. Takes a Serverpod project and adds necessary files for VPS deployment.

Constructors

TemplateGenerator()

Properties

hashCode int
The hash code for this object.
no setterinherited
projectDirectoryName String
The name of the project directory.
latefinal
projectDirectoryPath String
The path to the project directory.
latefinal
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userEmail String
The email address to use for SSL certificate notifications.
latefinal

Methods

checkDirectoryStructure() Future<bool>
Check if the current directory has the expected Serverpod project structure
findProjectName() String
Find project name by looking at _server and _client directory names
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run(List<String> arguments) Future<void>
Main entry point for the generator
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited